pub async fn test_insert_consecutive_identical_blocks<D: TestableDataSource>()Expand description
Regression test for a SQL bug.
In PostgreSQL, upserting with multiple conflicting rows in a single statement is not allowed.
pub async fn test_insert_consecutive_identical_blocks<D: TestableDataSource>()Regression test for a SQL bug.
In PostgreSQL, upserting with multiple conflicting rows in a single statement is not allowed.